@@ -115,9 +115,9 @@ void		_gedit_cmd_view_show_toolbar		(GtkAction   *action,
 							 GeditWindow *window);
 void		_gedit_cmd_view_show_statusbar		(GtkAction   *action,
 							 GeditWindow *window);
-void		_gedit_cmd_view_show_side_pane		(GtkAction   *action,
+void		_gedit_cmd_view_show_side_panel		(GtkAction   *action,
 							 GeditWindow *window);
-void		_gedit_cmd_view_show_bottom_pane	(GtkAction   *action,
+void		_gedit_cmd_view_show_bottom_panel	(GtkAction   *action,
 							 GeditWindow *window);
 void		_gedit_cmd_view_toggle_fullscreen_mode	(GtkAction   *action,
 							 GeditWindow *window);
@@ -145,6 +145,12 @@ void		_gedit_cmd_documents_next_document	(GtkAction   *action,
 							 GeditWindow *window);
 void		_gedit_cmd_documents_move_to_new_window	(GtkAction   *action,
 							 GeditWindow *window);
+void		_gedit_cmd_documents_new_tab_group	(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_documents_previous_tab_group	(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_documents_next_tab_group	(GtkAction   *action,
+							 GeditWindow *window);
 
 void		_gedit_cmd_help_contents		(GtkAction   *action,
 							 GeditWindow *window);
@@ -158,12 +164,6 @@ void		_gedit_cmd_file_save_documents_list	(GeditWindow *window,
 							 GList       *docs);
 
 
-#if !GTK_CHECK_VERSION (2, 17, 4)
-void		_gedit_cmd_file_page_setup		(GtkAction   *action,
-							 GeditWindow *window);
-#endif
-
-
 G_END_DECLS
 
 #endif /* __GEDIT_COMMANDS_H__ */ 
