@@ -90,9 +90,6 @@ static void	gedit_document_save_real	(GeditDocument                *doc,
 						 GeditDocumentNewlineType      newline_type,
 						 GeditDocumentCompressionType  compression_type,
 						 GeditDocumentSaveFlags        flags);
-static void	to_search_region_range 		(GeditDocument                *doc,
-						 GtkTextIter                  *start,
-						 GtkTextIter                  *end);
 static void 	insert_text_cb		 	(GeditDocument                *doc,
 						 GtkTextIter                  *pos,
 						 const gchar                  *text,
@@ -101,7 +98,7 @@ static void 	insert_text_cb		 	(GeditDocument                *doc,
 static void	delete_range_cb 		(GeditDocument                *doc,
 						 GtkTextIter                  *start,
 						 GtkTextIter                  *end);
-			     
+
 struct _GeditDocumentPrivate
 {
 	GSettings   *editor_settings;
@@ -734,7 +731,7 @@ gedit_document_class_init (GeditDocumentClass *klass)
 }
 
 static void
-set_language (GeditDocument     *doc, 
+set_language (GeditDocument     *doc,
               GtkSourceLanguage *lang,
               gboolean           set_by_user)
 {
@@ -1143,6 +1140,11 @@ set_content_type (GeditDocument *doc,
 	}
 }
 
+/**
+ * gedit_document_set_content_type:
+ * @doc:
+ * @content_type: (allow-none):
+ */
 void
 gedit_document_set_content_type (GeditDocument *doc,
                                  const gchar   *content_type)
@@ -1207,7 +1209,12 @@ gedit_document_set_location (GeditDocument *doc,
 	set_content_type (doc, NULL);
 }
 
-/* Never returns NULL */
+/**
+ * gedit_document_get_uri_for_display:
+ * @doc:
+ *
+ * Note: this never returns %NULL.
+ **/
 gchar *
 gedit_document_get_uri_for_display (GeditDocument *doc)
 {
@@ -1224,7 +1231,12 @@ gedit_document_get_uri_for_display (GeditDocument *doc)
 	}
 }
 
-/* Never returns NULL */
+/**
+ * gedit_document_get_short_name_for_display:
+ * @doc:
+ *
+ * Note: this never returns %NULL.
+ **/
 gchar *
 gedit_document_get_short_name_for_display (GeditDocument *doc)
 {
@@ -1245,6 +1257,11 @@ gedit_document_get_short_name_for_display (GeditDocument *doc)
 	}
 }
 
+/**
+ * gedit_document_set_short_name_for_display:
+ * @doc:
+ * @short_name: (allow-none):
+ */
 void
 gedit_document_set_short_name_for_display (GeditDocument *doc,
                                            const gchar   *short_name)
@@ -1265,7 +1282,12 @@ gedit_document_get_content_type (GeditDocument *doc)
  	return g_strdup (doc->priv->content_type);
 }
 
-/* Never returns NULL */
+/**
+ * gedit_document_get_mime_type:
+ * @doc:
+ *
+ * Note: this never returns %NULL.
+ **/
 gchar *
 gedit_document_get_mime_type (GeditDocument *doc)
 {
@@ -1584,6 +1606,14 @@ gedit_document_load_real (GeditDocument       *doc,
 	gedit_document_loader_load (doc->priv->loader);
 }
 
+/**
+ * gedit_document_load_stream:
+ * @doc:
+ * @stream:
+ * @encoding: (allow-none):
+ * @line_pop:
+ * @column_pos:
+ **/
 void
 gedit_document_load_stream (GeditDocument       *doc,
                             GInputStream        *stream,
@@ -1620,7 +1650,7 @@ gedit_document_load_stream (GeditDocument       *doc,
  * gedit_document_load:
  * @doc: the #GeditDocument.
  * @location: the location where to load the document from.
- * @encoding: the #GeditEncoding to encode the document.
+ * @encoding: (allow-none): the #GeditEncoding to encode the document, or %NULL.
  * @line_pos: the line to show.
  * @create: whether the document should be created if it doesn't exist.
  *
@@ -1963,6 +1993,40 @@ compute_num_of_lines (const gchar *text)
 	return n;
 }
 
+static void
+to_search_region_range (GeditDocument *doc,
+			GtkTextIter   *start,
+			GtkTextIter   *end)
+{
+	gedit_debug (DEBUG_DOCUMENT);
+
+	if (doc->priv->to_search_region == NULL)
+		return;
+
+	gtk_text_iter_set_line_offset (start, 0);
+	gtk_text_iter_forward_to_line_end (end);
+
+	/*
+	g_print ("+ [%u (%u), %u (%u)]\n", gtk_text_iter_get_line (start), gtk_text_iter_get_offset (start),
+					   gtk_text_iter_get_line (end), gtk_text_iter_get_offset (end));
+	*/
+
+	/* Add the region to the refresh region */
+	gedit_text_region_add (doc->priv->to_search_region, start, end);
+
+	/* Notify views of the updated highlight region */
+	gtk_text_iter_backward_lines (start, doc->priv->num_of_lines_search_text);
+	gtk_text_iter_forward_lines (end, doc->priv->num_of_lines_search_text);
+
+	g_signal_emit (doc, document_signals [SEARCH_HIGHLIGHT_UPDATED], 0, start, end);
+}
+
+/**
+ * gedit_document_set_search_text"
+ * @doc:
+ * @text: (allow-none):
+ * @flags:
+ **/
 void
 gedit_document_set_search_text (GeditDocument *doc,
 				const gchar   *text,
@@ -2025,6 +2089,11 @@ gedit_document_set_search_text (GeditDocument *doc,
 		g_object_notify (G_OBJECT (doc), "can-search-again");
 }
 
+/**
+ * gedit_document_get_search_text:
+ * @doc:
+ * @flags: (allow-none):
+ */
 gchar *
 gedit_document_get_search_text (GeditDocument *doc,
 				guint         *flags)
@@ -2046,6 +2115,14 @@ gedit_document_get_can_search_again (GeditDocument *doc)
 	        (*doc->priv->search_text != '\0'));
 }
 
+/**
+ * gedit_document_search_forward:
+ * @doc:
+ * @start: (allow-none):
+ * @end: (allow-none):
+ * @match_start: (allow-none):
+ * @match_end: (allow=none):
+ **/
 gboolean
 gedit_document_search_forward (GeditDocument     *doc,
 			       const GtkTextIter *start,
@@ -2118,7 +2195,15 @@ gedit_document_search_forward (GeditDocument     *doc,
 	
 	return found;			    
 }
-						 
+
+/**
+ * gedit_document_search_backward:
+ * @doc:
+ * @start: (allow-none):
+ * @end: (allow-none):
+ * @match_start: (allow-none):
+ * @match_end: (allow=none):
+ **/
 gboolean
 gedit_document_search_backward (GeditDocument     *doc,
 				const GtkTextIter *start,
@@ -2192,6 +2277,7 @@ gedit_document_search_backward (GeditDocument     *doc,
 	return found;		      
 }
 
+/* FIXME this is an issue for introspection regardning @find */
 gint 
 gedit_document_replace_all (GeditDocument       *doc,
 			    const gchar         *find, 
@@ -2309,54 +2395,26 @@ gedit_document_replace_all (GeditDocument       *doc,
 	return cont;
 }
 
-void
-gedit_document_set_language (GeditDocument     *doc, 
-			     GtkSourceLanguage *lang)
-{
-	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
-
-	set_language (doc, lang, TRUE);
-}
-
-GtkSourceLanguage *
-gedit_document_get_language (GeditDocument *doc)
-{
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), NULL);
-
-	return gtk_source_buffer_get_language (GTK_SOURCE_BUFFER (doc));
-}
-
-const GeditEncoding *
-gedit_document_get_encoding (GeditDocument *doc)
-{
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), NULL);
-
-	return doc->priv->encoding;
-}
-
-glong
-_gedit_document_get_seconds_since_last_save_or_load (GeditDocument *doc)
-{
-	GTimeVal current_time;
-
-	gedit_debug (DEBUG_DOCUMENT);
-	
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), -1);
-
-	g_get_current_time (&current_time);
-
-	return (current_time.tv_sec - doc->priv->time_of_last_save_or_load.tv_sec);
-}
-
 static void
 get_search_match_colors (GeditDocument *doc,
 			 gboolean      *foreground_set,
 			 GdkColor      *foreground,
 			 gboolean      *background_set,
-			 GdkColor      *background)
+			 GdkColor      *background,
+			 gboolean      *line_background_set,
+			 GdkColor      *line_background,
+			 gboolean      *bold_set,
+			 gboolean      *bold,
+			 gboolean      *italic_set,
+			 gboolean      *italic,
+			 gboolean      *underline_set,
+			 gboolean      *underline,
+			 gboolean      *strikethrough_set,
+			 gboolean      *strikethrough)
 {
 	GtkSourceStyleScheme *style_scheme;
 	GtkSourceStyle *style;
+	gchar *line_bg;
 	gchar *bg;
 	gchar *fg;
 
@@ -2369,11 +2427,21 @@ get_search_match_colors (GeditDocument *doc,
 	if (style == NULL)
 		goto fallback;
 
-	g_object_get (style, 
+	g_object_get (style,
 		      "foreground-set", foreground_set, 
 		      "foreground", &fg,
-		      "background-set", background_set, 
+		      "background-set", background_set,
 		      "background", &bg,
+		      "line-background-set", line_background_set,
+		      "line-background", &line_bg,
+		      "bold-set", bold_set,
+		      "bold", bold,
+		      "italic-set", italic_set,
+		      "italic", italic,
+		      "underline-set", underline_set,
+		      "underline", underline,
+		      "strikethrough-set", strikethrough_set,
+		      "strikethrough", strikethrough,
 		      NULL);
 
 	if (*foreground_set)
@@ -2391,10 +2459,20 @@ get_search_match_colors (GeditDocument *doc,
 		{
 			*background_set = FALSE;
 		}
-	}	
+	}
+
+	if (*line_background_set)
+	{
+		if (line_bg == NULL ||
+		    !gdk_color_parse (line_bg, background))
+		{
+			*line_background_set = FALSE;
+		}
+	}
 
 	g_free (fg);
 	g_free (bg);
+	g_free (line_bg);
 
 	return;
 
@@ -2417,8 +2495,18 @@ sync_found_tag (GeditDocument *doc,
 {
 	GdkColor fg;
 	GdkColor bg;
+	GdkColor line_bg;
 	gboolean fg_set;
 	gboolean bg_set;
+	gboolean line_bg_set;
+	gboolean bold;
+	gboolean italic;
+	gboolean underline;
+	gboolean strikethrough;
+	gboolean bold_set;
+	gboolean italic_set;
+	gboolean underline_set;
+	gboolean strikethrough_set;
 
 	gedit_debug (DEBUG_DOCUMENT);
 
@@ -2426,14 +2514,26 @@ sync_found_tag (GeditDocument *doc,
 
 	get_search_match_colors (doc,
 				 &fg_set, &fg,
-				 &bg_set, &bg);
+				 &bg_set, &bg,
+				 &line_bg_set, &line_bg,
+				 &bold_set, &bold,
+				 &italic_set, &italic,
+				 &underline_set, &underline,
+				 &strikethrough_set, &strikethrough);
+
+	g_object_freeze_notify (G_OBJECT (doc->priv->found_tag));
 
 	g_object_set (doc->priv->found_tag,
 		      "foreground-gdk", fg_set ? &fg : NULL,
-		      NULL);
-	g_object_set (doc->priv->found_tag,
 		      "background-gdk", bg_set ? &bg : NULL,
+		      "paragraph-background-gdk", line_bg_set ? &line_bg : NULL,
+		      "weight", bold_set && bold ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL,
+		      "style", italic_set && italic ? PANGO_STYLE_ITALIC : PANGO_STYLE_NORMAL,
+		      "underline", underline_set && underline ? PANGO_UNDERLINE_SINGLE : PANGO_UNDERLINE_NONE,
+		      "strikethrough", strikethrough_set && strikethrough,
 		      NULL);
+
+	g_object_thaw_notify (G_OBJECT (doc->priv->found_tag));
 }
 
 static void
@@ -2563,34 +2663,6 @@ search_region (GeditDocument *doc,
 	} while (found);
 }
 
-static void
-to_search_region_range (GeditDocument *doc,
-			GtkTextIter   *start, 
-			GtkTextIter   *end)
-{
-	gedit_debug (DEBUG_DOCUMENT);
-	
-	if (doc->priv->to_search_region == NULL)
-		return;
-		
-	gtk_text_iter_set_line_offset (start, 0);
-	gtk_text_iter_forward_to_line_end (end);
-	
-	/*
-	g_print ("+ [%u (%u), %u (%u)]\n", gtk_text_iter_get_line (start), gtk_text_iter_get_offset (start),
-					   gtk_text_iter_get_line (end), gtk_text_iter_get_offset (end));
-	*/
-
-	/* Add the region to the refresh region */
-	gedit_text_region_add (doc->priv->to_search_region, start, end);
-
-	/* Notify views of the updated highlight region */
-	gtk_text_iter_backward_lines (start, doc->priv->num_of_lines_search_text);
-	gtk_text_iter_forward_lines (end, doc->priv->num_of_lines_search_text);
-	
-	g_signal_emit (doc, document_signals [SEARCH_HIGHLIGHT_UPDATED], 0, start, end);
-}
-
 void
 _gedit_document_search_region (GeditDocument     *doc,
 			       const GtkTextIter *start,
@@ -2687,6 +2759,50 @@ delete_range_cb (GeditDocument *doc,
 	to_search_region_range (doc, &d_start, &d_end);
 }
 
+/**
+ * gedit_document_set_language:
+ * @doc:
+ * @lang: (allow-none):
+ **/
+void
+gedit_document_set_language (GeditDocument     *doc,
+			     GtkSourceLanguage *lang)
+{
+	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
+
+	set_language (doc, lang, TRUE);
+}
+
+GtkSourceLanguage *
+gedit_document_get_language (GeditDocument *doc)
+{
+	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), NULL);
+
+	return gtk_source_buffer_get_language (GTK_SOURCE_BUFFER (doc));
+}
+
+const GeditEncoding *
+gedit_document_get_encoding (GeditDocument *doc)
+{
+	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), NULL);
+
+	return doc->priv->encoding;
+}
+
+glong
+_gedit_document_get_seconds_since_last_save_or_load (GeditDocument *doc)
+{
+	GTimeVal current_time;
+
+	gedit_debug (DEBUG_DOCUMENT);
+
+	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), -1);
+
+	g_get_current_time (&current_time);
+
+	return (current_time.tv_sec - doc->priv->time_of_last_save_or_load.tv_sec);
+}
+
 void
 gedit_document_set_enable_search_highlighting (GeditDocument *doc,
 					       gboolean       enable)
