@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-history-entry.h 5344 2006-12-07 17:11:52Z paolo $
+ * $Id$
  */
 
 #ifndef __GEDIT_HISTORY_ENTRY_H__
@@ -58,7 +58,7 @@ struct _GeditHistoryEntry
 	GeditHistoryEntryPrivate *priv;
 };
 
-GType		 gedit_history_entry_get_type	(void) G_GNUC_CONST;
+GType		 gedit_history_entry_get_type		(void) G_GNUC_CONST;
 
 GtkWidget	*gedit_history_entry_new		(const gchar       *history_id,
 							 gboolean           enable_completion);
@@ -86,7 +86,13 @@ gboolean         gedit_history_entry_get_enable_completion
 							(GeditHistoryEntry *entry);
 
 GtkWidget	*gedit_history_entry_get_entry		(GeditHistoryEntry *entry);
-							 
+
+typedef gchar * (* GeditHistoryEntryEscapeFunc) (const gchar *str);
+void		gedit_history_entry_set_escape_func	(GeditHistoryEntry *entry,
+							 GeditHistoryEntryEscapeFunc escape_func);
+
 G_END_DECLS
 
 #endif /* __GEDIT_HISTORY_ENTRY_H__ */
+
+/* ex:ts=8:noet: */
