@@ -31,6 +31,7 @@
 #define __GEDIT_METADATA_MANAGER_H__
 
 #include <glib.h>
+#include <gio/gio.h>
 
 G_BEGIN_DECLS
 
@@ -39,12 +40,14 @@ G_BEGIN_DECLS
 void		 gedit_metadata_manager_shutdown 	(void);
 
 
-gchar		*gedit_metadata_manager_get 		(const gchar *uri,
+gchar		*gedit_metadata_manager_get 		(GFile       *location,
 					     		 const gchar *key);
-void		 gedit_metadata_manager_set		(const gchar *uri,
+void		 gedit_metadata_manager_set		(GFile       *location,
 							 const gchar *key,
 							 const gchar *value);
 
 G_END_DECLS
 
 #endif /* __GEDIT_METADATA_MANAGER_H__ */
+
+/* ex:ts=8:noet: */
