@@ -135,8 +135,14 @@ GtkWidget	*_gedit_tab_new_from_location	(GFile               *location,
 						 gint                 line_pos,
 						 gint                 column_pos,
 						 gboolean             create);
+
+GtkWidget	*_gedit_tab_new_from_stream	(GInputStream        *stream,
+						 const GeditEncoding *encoding,
+						 gint                 line_pos,
+						 gint                 column_pos);
+
 gchar 		*_gedit_tab_get_name		(GeditTab            *tab);
-gchar 		*_gedit_tab_get_tooltips	(GeditTab            *tab);
+gchar 		*_gedit_tab_get_tooltip		(GeditTab            *tab);
 GdkPixbuf 	*_gedit_tab_get_icon		(GeditTab            *tab);
 void		 _gedit_tab_load		(GeditTab            *tab,
 						 GFile               *location,
@@ -144,12 +150,20 @@ void		 _gedit_tab_load		(GeditTab            *tab,
 						 gint                 line_pos,
 						 gint                 column_pos,
 						 gboolean             create);
+
+void		 _gedit_tab_load_stream		(GeditTab            *tab,
+						 GInputStream        *location,
+						 const GeditEncoding *encoding,
+						 gint                 line_pos,
+						 gint                 column_pos);
+
 void		 _gedit_tab_revert		(GeditTab            *tab);
 void		 _gedit_tab_save		(GeditTab            *tab);
 void		 _gedit_tab_save_as		(GeditTab            *tab,
 						 GFile               *location,
 						 const GeditEncoding *encoding,
-						 GeditDocumentNewlineType newline_type);
+						 GeditDocumentNewlineType newline_type,
+						 GeditDocumentCompressionType compression_type);
 
 void		 _gedit_tab_print		(GeditTab            *tab);
 void		 _gedit_tab_print_preview	(GeditTab            *tab);
@@ -158,11 +172,9 @@ void		 _gedit_tab_mark_for_closing	(GeditTab	     *tab);
 
 gboolean	 _gedit_tab_can_close		(GeditTab	     *tab);
 
-#if !GTK_CHECK_VERSION (2, 17, 4)
-void		 _gedit_tab_page_setup		(GeditTab            *tab);
-#endif
 
 G_END_DECLS
 
 #endif  /* __GEDIT_TAB_H__  */
+
 /* ex:ts=8:noet: */
