@@ -63,11 +63,12 @@
 #include <sys/stat.h>
 #endif
 
-#include "gseal-gtk-compat.h"
-
 #define STDIN_DELAY_MICROSECONDS 100000
 
-/* Returns true if location is a file: uri and is not a chained uri */
+/**
+ * gedit_utils_location_has_file_scheme:
+ *
+ * Returns: %TRUE if @location is a file: uri and is not a chained uri */
 gboolean
 gedit_utils_location_has_file_scheme (GFile *location)
 {
@@ -261,11 +262,12 @@ finally_2:
 }
 
 /**
- * gedit_utils_set_atk_name_description
- * @widget : The Gtk widget for which name/description to be set
- * @name : Atk name string
- * @description : Atk description string
- * Description : This function sets up name and description
+ * gedit_utils_set_atk_name_description:
+ * @widget: The Gtk widget for which name/description to be set
+ * @name: Atk name string
+ * @description: Atk description string
+ *
+ * This function sets up name and description
  * for a specified gtk widget.
  */
 void
@@ -288,10 +290,12 @@ gedit_utils_set_atk_name_description (GtkWidget   *widget,
 }
 
 /**
- * gedit_set_atk__relation
- * @obj1,@obj2 : specified widgets.
- * @rel_type : the type of relation to set up.
- * Description : This function establishes atk relation
+ * gedit_set_atk_relation:
+ * @obj1: specified widget.
+ * @obj2: specified widget.
+ * @rel_type: the type of relation to set up.
+ *
+ * This function establishes atk relation
  * between 2 specified widgets.
  */
 void
@@ -670,7 +674,11 @@ gedit_utils_make_valid_utf8 (const char *name)
 	return g_string_free (string, FALSE);
 }
 
-/* Note that this function replace home dir with ~ */
+/**
+ * gedit_utils_uri_get_dirname:
+ *
+ * Note: this function replace home dir with ~
+ */
 gchar *
 gedit_utils_uri_get_dirname (const gchar *uri)
 {
@@ -819,7 +827,9 @@ gedit_utils_replace_home_dir_with_tilde (const gchar *uri)
 /* the following two functions are courtesy of galeon */
 
 /**
- * gedit_utils_get_current_workspace: Get the current workspace
+ * gedit_utils_get_current_workspace:
+ *
+ * Get the current workspace
  *
  * Get the currently visible workspace for the #GdkScreen.
  *
@@ -868,7 +878,9 @@ gedit_utils_get_current_workspace (GdkScreen *screen)
 }
 
 /**
- * gedit_utils_get_window_workspace: Get the workspace the window is on
+ * gedit_utils_get_window_workspace:
+ *
+ * Get the workspace the window is on
  *
  * This function gets the workspace that the #GtkWindow is visible on,
  * it returns GEDIT_ALL_WORKSPACES if the window is sticky, or if
@@ -917,7 +929,9 @@ gedit_utils_get_window_workspace (GtkWindow *gtkwindow)
 }
 
 /**
- * gedit_utils_get_current_viewport: Get the current viewport origin
+ * gedit_utils_get_current_viewport:
+ *
+ * Get the current viewport origin
  *
  * Get the currently visible viewport origin for the #GdkScreen.
  *
@@ -1092,21 +1106,22 @@ handle_builder_error (const gchar *message, ...)
 	return label;
 }
 
+/* FIXME this is an issue for introspection */
 /**
  * gedit_utils_get_ui_objects:
  * @filename: the path to the gtk builder file
- * @root_objects: a NULL terminated list of root objects to load or NULL to
+ * @root_objects: a %NULL terminated list of root objects to load or NULL to
  *                load all objects
  * @error_widget: a pointer were a #GtkLabel
  * @object_name: the name of the first object
  * @...: a pointer were the first object is returned, followed by more
- *       name / object pairs and terminated by NULL.
+ *       name / object pairs and terminated by %NULL.
  *
  * This function gets the requested objects from a GtkBuilder ui file. In case
- * of error it returns FALSE and sets error_widget to a GtkLabel containing
+ * of error it returns %FALSE and sets error_widget to a GtkLabel containing
  * the error message to display.
  *
- * Returns FALSE if an error occurs, TRUE on success.
+ * Returns: %FALSE if an error occurs, %TRUE on success.
  */
 gboolean
 gedit_utils_get_ui_objects (const gchar  *filename,
@@ -1241,7 +1256,7 @@ gedit_utils_make_canonical_uri_from_shell_arg (const gchar *str)
  * gedit_utils_file_has_parent:
  * @gfile: the GFile to check the parent for
  *
- * Return TRUE if the specified gfile has a parent (is not the root), FALSE
+ * Return %TRUE if the specified gfile has a parent (is not the root), %FALSE
  * otherwise
  */
 gboolean
@@ -1365,11 +1380,10 @@ gedit_utils_uri_for_display (GFile *location)
 /**
  * gedit_utils_drop_get_uris:
  * @selection_data: the #GtkSelectionData from drag_data_received
- * @info: the info from drag_data_received
  *
  * Create a list of valid uri's from a uri-list drop.
  * 
- * Return value: a string array which will hold the uris or NULL if there 
+ * Return value: a string array which will hold the uris or %NULL if there 
  *		 were no valid uris. g_strfreev should be used when the 
  *		 string array is no longer used
  */
@@ -1414,26 +1428,27 @@ null_ptr (gchar **ptr)
 /**
  * gedit_utils_decode_uri:
  * @uri: the uri to decode
- * @scheme: return value pointer for the uri's scheme (e.g. http, sftp, ...)
- * @user: return value pointer for the uri user info
- * @port: return value pointer for the uri port
- * @host: return value pointer for the uri host
- * @path: return value pointer for the uri path
+ * @scheme: (allow-none): return value pointer for the uri's
+ * scheme (e.g. http, sftp, ...), or %NULL
+ * @user: (allow-none): return value pointer for the uri user info, or %NULL
+ * @port: (allow-none): return value pointer for the uri port, or %NULL
+ * @host: (allow-none): return value pointer for the uri host, or %NULL
+ * @path: (allow-none): return value pointer for the uri path, or %NULL
  *
  * Parse and break an uri apart in its individual components like the uri
  * scheme, user info, port, host and path. The return value pointer can be
- * NULL to ignore certain parts of the uri. If the function returns TRUE, then
+ * %NULL to ignore certain parts of the uri. If the function returns %TRUE, then
  * all return value pointers should be freed using g_free
  * 
- * Return value: TRUE if the uri could be properly decoded, FALSE otherwise.
+ * Return value: %TRUE if the uri could be properly decoded, %FALSE otherwise.
  */
 gboolean
-gedit_utils_decode_uri (const gchar *uri,
-			gchar **scheme,
-			gchar **user,
-			gchar **host,
-			gchar **port,
-			gchar **path
+gedit_utils_decode_uri (const gchar  *uri,
+			gchar       **scheme,
+			gchar       **user,
+			gchar       **host,
+			gchar       **port,
+			gchar       **path
 )
 {
 	/* Largely copied from glib/gio/gdummyfile.c:_g_decode_uri. This 
