@@ -30,7 +30,6 @@
 #include <glib/gi18n-lib.h>
 #include <gdk/gdkkeysyms.h>
 #include <gedit/gedit-utils.h>
-#include <gedit/gedit-plugin.h>
 
 #include "gedit-file-browser-utils.h"
 #include "gedit-file-browser-error.h"
@@ -234,8 +233,7 @@ static void on_action_filter_binary            (GtkAction              *action,
 static void on_action_bookmark_open            (GtkAction              *action,
 						GeditFileBrowserWidget *obj);
 
-GEDIT_PLUGIN_DEFINE_TYPE (GeditFileBrowserWidget, gedit_file_browser_widget,
-	                  GTK_TYPE_VBOX)
+G_DEFINE_DYNAMIC_TYPE (GeditFileBrowserWidget, gedit_file_browser_widget, GTK_TYPE_VBOX)
 
 static void
 free_name_icon (gpointer data)
@@ -487,6 +485,11 @@ gedit_file_browser_widget_class_init (GeditFileBrowserWidgetClass *klass)
 				  sizeof (GeditFileBrowserWidgetPrivate));
 }
 
+static void
+gedit_file_browser_widget_class_finalize (GeditFileBrowserWidgetClass *klass)
+{
+}
+
 static void
 add_signal (GeditFileBrowserWidget *obj,
 	    gpointer                object,
@@ -546,7 +549,12 @@ get_from_bookmark_file (GeditFileBrowserWidget  *obj,
 	item = (NameIcon *)data;
 
 	*name = g_strdup (item->name);
-	*icon = g_object_ref (item->icon);
+	*icon = item->icon;
+
+	if (item->icon != NULL)
+	{
+		g_object_ref (item->icon);
+	}
 
 	return TRUE;
 }
@@ -3211,4 +3219,10 @@ on_action_bookmark_open (GtkAction              *action,
 		bookmark_open (obj, model, &iter);
 }
 
+void
+_gedit_file_browser_widget_register_type (GTypeModule *type_module)
+{
+	gedit_file_browser_widget_register_type (type_module);
+}
+
 /* ex:ts=8:noet: */
