@@ -30,7 +30,7 @@
 #ifndef __GEDIT_SPELL_CHECKER_DIALOG_H__
 #define __GEDIT_SPELL_CHECKER_DIALOG_H__
 
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 #include "gedit-spell-checker.h"
 
 G_BEGIN_DECLS
@@ -70,9 +70,10 @@ struct _GeditSpellCheckerDialogClass
 GType        		 gedit_spell_checker_dialog_get_type	(void) G_GNUC_CONST;
 
 /* Constructors */
-GtkWidget		*gedit_spell_checker_dialog_new		(void);
+GtkWidget		*gedit_spell_checker_dialog_new		(const gchar *data_dir);
 GtkWidget		*gedit_spell_checker_dialog_new_from_spell_checker 
-								(GeditSpellChecker *spell);
+								(GeditSpellChecker *spell,
+								 const gchar *data_dir);
 
 void 			 gedit_spell_checker_dialog_set_spell_checker
 								(GeditSpellCheckerDialog *dlg,
@@ -89,3 +90,4 @@ G_END_DECLS
 
 #endif  /* __GEDIT_SPELL_CHECKER_DIALOG_H__ */
 
+/* ex:ts=8:noet: */
