@@ -24,7 +24,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-taglist-plugin.c 6745 2008-12-28 21:27:48Z icq $
+ * $Id$
  */
 
 #ifdef HAVE_CONFIG_H
@@ -35,25 +35,31 @@
 #include "gedit-taglist-plugin-panel.h"
 #include "gedit-taglist-plugin-parser.h"
 
-#include <glib/gi18n-lib.h>
-#include <gmodule.h>
+#include <glib/gi18n.h>
 
-#include <gedit/gedit-plugin.h>
+#include <gedit/gedit-window.h>
+#include <gedit/gedit-window-activatable.h>
 #include <gedit/gedit-debug.h>
 
-#define WINDOW_DATA_KEY "GeditTaglistPluginWindowData"
-
 #define GEDIT_TAGLIST_PLUGIN_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), GEDIT_TYPE_TAGLIST_PLUGIN, GeditTaglistPluginPrivate))
 
+static void gedit_window_activatable_iface_init (GeditWindowActivatableInterface *iface);
+
+G_DEFINE_DYNAMIC_TYPE_EXTENDED (GeditTaglistPlugin,
+				gedit_taglist_plugin,
+				PEAS_TYPE_EXTENSION_BASE,
+				0,
+				G_IMPLEMENT_INTERFACE_DYNAMIC (GEDIT_TYPE_WINDOW_ACTIVATABLE,
+							       gedit_window_activatable_iface_init)	\
+													\
+				_gedit_taglist_plugin_panel_register_type (type_module);		\
+)
+
 struct _GeditTaglistPluginPrivate
 {
-	gpointer dummy;
+	GtkWidget *taglist_panel;
 };
 
-GEDIT_PLUGIN_REGISTER_TYPE_WITH_CODE (GeditTaglistPlugin, gedit_taglist_plugin,
-	gedit_taglist_plugin_panel_register_type (module);
-)
-
 static void
 gedit_taglist_plugin_init (GeditTaglistPlugin *plugin)
 {
@@ -65,81 +71,69 @@ gedit_taglist_plugin_init (GeditTaglistPlugin *plugin)
 static void
 gedit_taglist_plugin_finalize (GObject *object)
 {
-/*
-	GeditTaglistPlugin *plugin = GEDIT_TAGLIST_PLUGIN (object);
-*/
 	gedit_debug_message (DEBUG_PLUGINS, "GeditTaglistPlugin finalizing");
 
 	free_taglist ();
-	
+
 	G_OBJECT_CLASS (gedit_taglist_plugin_parent_class)->finalize (object);
 }
 
 static void
-impl_activate (GeditPlugin *plugin,
-	       GeditWindow *window)
+gedit_taglist_plugin_activate (GeditWindowActivatable *activatable,
+			       GeditWindow            *window)
 {
+	GeditTaglistPluginPrivate *priv;
 	GeditPanel *side_panel;
-	GtkWidget *taglist_panel;
 	gchar *data_dir;
-	
+
 	gedit_debug (DEBUG_PLUGINS);
-	
-	g_return_if_fail (g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY) == NULL);
-	
+
+	priv = GEDIT_TAGLIST_PLUGIN (activatable)->priv;
+
 	side_panel = gedit_window_get_side_panel (window);
-	
-	data_dir = gedit_plugin_get_data_dir (plugin);
-	taglist_panel = gedit_taglist_plugin_panel_new (window, data_dir);
+
+	data_dir = peas_extension_base_get_data_dir (PEAS_EXTENSION_BASE (activatable));
+	priv->taglist_panel = gedit_taglist_plugin_panel_new (window, data_dir);
 	g_free (data_dir);
-	
-	gedit_panel_add_item_with_stock_icon (side_panel, 
-					      taglist_panel, 
-					      _("Tags"), 
-					      GTK_STOCK_ADD);
 
-	g_object_set_data (G_OBJECT (window), 
-			   WINDOW_DATA_KEY,
-			   taglist_panel);
+	gedit_panel_add_item_with_stock_icon (side_panel,
+					      priv->taglist_panel,
+					      "GeditTagListPanel",
+					      _("Tags"),
+					      GTK_STOCK_ADD);
 }
 
 static void
-impl_deactivate	(GeditPlugin *plugin,
-		 GeditWindow *window)
+gedit_taglist_plugin_deactivate (GeditWindowActivatable *activatable,
+				 GeditWindow            *window)
 {
+	GeditTaglistPluginPrivate *priv;
 	GeditPanel *side_panel;
-	gpointer data;
-	
+
 	gedit_debug (DEBUG_PLUGINS);
-	
-	data = g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
-	g_return_if_fail (data != NULL);
-	
+
+	priv = GEDIT_TAGLIST_PLUGIN (activatable)->priv;
+
 	side_panel = gedit_window_get_side_panel (window);
 
-	gedit_panel_remove_item (side_panel, 
-			      	 GTK_WIDGET (data));
-			      
-	g_object_set_data (G_OBJECT (window), 
-			   WINDOW_DATA_KEY,
-			   NULL);
+	gedit_panel_remove_item (side_panel,
+				 priv->taglist_panel);
 }
 
 static void
-impl_update_ui	(GeditPlugin *plugin,
-		 GeditWindow *window)
+gedit_taglist_plugin_update_state (GeditWindowActivatable *activatable,
+				   GeditWindow            *window)
 {
-	gpointer data;
+	GeditTaglistPluginPrivate *priv;
 	GeditView *view;
-	
+
 	gedit_debug (DEBUG_PLUGINS);
-	
-	data = g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
-	g_return_if_fail (data != NULL);
-	
+
+	priv = GEDIT_TAGLIST_PLUGIN (activatable)->priv;
+
 	view = gedit_window_get_active_view (window);
-	
-	gtk_widget_set_sensitive (GTK_WIDGET (data),
+
+	gtk_widget_set_sensitive (priv->taglist_panel,
 				  (view != NULL) &&
 				  gtk_text_view_get_editable (GTK_TEXT_VIEW (view)));
 }
@@ -148,13 +142,33 @@ static void
 gedit_taglist_plugin_class_init (GeditTaglistPluginClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	GeditPluginClass *plugin_class = GEDIT_PLUGIN_CLASS (klass);
 
 	object_class->finalize = gedit_taglist_plugin_finalize;
 
-	plugin_class->activate = impl_activate;
-	plugin_class->deactivate = impl_deactivate;
-	plugin_class->update_ui = impl_update_ui;
-
 	g_type_class_add_private (object_class, sizeof (GeditTaglistPluginPrivate));
 }
+
+static void
+gedit_taglist_plugin_class_finalize (GeditTaglistPluginClass *klass)
+{
+}
+
+static void
+gedit_window_activatable_iface_init (GeditWindowActivatableInterface *iface)
+{
+	iface->activate = gedit_taglist_plugin_activate;
+	iface->deactivate = gedit_taglist_plugin_deactivate;
+	iface->update_state = gedit_taglist_plugin_update_state;
+}
+
+G_MODULE_EXPORT void
+peas_register_types (PeasObjectModule *module)
+{
+	gedit_taglist_plugin_register_type (G_TYPE_MODULE (module));
+
+	peas_object_module_register_extension_type (module,
+						    GEDIT_TYPE_WINDOW_ACTIVATABLE,
+						    GEDIT_TYPE_TAGLIST_PLUGIN);
+}
+
+/* ex:ts=8:noet: */
